@@ -93,8 +93,18 @@ class Declaration(ParseNode):
         """ Warning on unknown declaration
             and write current in outstring.
         """
-        if ( not SORTING.has_key(self.name.strip('*_'))
-                and self.root.get_opt('warn') ):
+        name = self.name.strip('*_#')
+        if name.startswith('-moz-'):
+            name = name[5:]
+        elif name.startswith('-webkit-'):
+            name = name[8:]
+        elif name.startswith('-o-'):
+            name = name[3:]
+        elif name.startswith('-ms-'):
+            name = name[4:]
+
+        if (not SORTING.has_key(name)
+                and self.root.get_opt('warn')):
             warn("Unknown declaration: %s" % self.name)
 
         return (":%s" % self.root.cache['delims'][1] ).join(
@@ -199,7 +209,8 @@ class Stylesheet(object):
         self.setup()
         Node.root = self
 
-    def setup(self):
+    @staticmethod
+    def setup():
 
         # Values
         NUMBER_VALUE.setParseAction(NumberValue)
@@ -282,7 +293,8 @@ class Stylesheet(object):
         self.cache['mix'].update(cache.get('mix'))
         map(self.set_var, cache['ctx'].values())
 
-    def scan(self, src):
+    @staticmethod
+    def scan(src):
         """ Scan scss from string and return nodes.
         """
         assert isinstance(src, basestring)
