@@ -6,7 +6,7 @@ from scss.parser import Stylesheet
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylesheet()
+        self.parser = Stylesheet(options=dict(compress=True))
 
     def test_variables(self):
         src = """
@@ -32,7 +32,7 @@ class TestSCSS( unittest.TestCase ):
                 }
             }
             """
-        test = "table.hl {\n\tmargin: 2em 0}\n\ntable.hl td.ln {\n\ttext-align: right}\n\ntable.hl td.ln li {\n\tcolor: #f00}\n\ntable.hl td.ln:hover {\n\twidth: 20px}\n\nli {\n\tfont-weight: bold;\n\tfont-size: 1.2em;\n\tfont-family: serif}\n\n"
+        test = "table.hl{margin:2em 0}table.hl td.ln{text-align:right}table.hl td.ln li{color:#f00}table.hl td.ln:hover{width:20px}li{font-weight:bold;font-size:1.2em;font-family:serif}"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
